diff --git theme/views-view.tpl.php theme/views-view.tpl.php
index e19c09b..aa5c103 100644
--- theme/views-view.tpl.php
+++ theme/views-view.tpl.php
@@ -39,7 +39,7 @@
   <?php endif; ?>
 
   <?php if ($attachment_before): ?>
-    <div class="attachment-before">
+    <div class="attachment attachment-before">
       <?php print $attachment_before; ?>
     </div>
   <?php endif; ?>
@@ -59,7 +59,7 @@
   <?php endif; ?>
 
   <?php if ($attachment_after): ?>
-    <div class="attachment-after">
+    <div class="attachment attachment-after">
       <?php print $attachment_after; ?>
     </div>
   <?php endif; ?>

diff --git js/ajax_view.js js/ajax_view.js
index 8470058..ef4372f 100644
--- js/ajax_view.js
+++ js/ajax_view.js
@@ -107,8 +107,8 @@ Drupal.behaviors.ViewsAjaxView = function() {
           var target = this;
           $(this)
             .addClass('views-processed')
-            // Process pager, tablesort, and summary links.
-            .find('ul.pager > li > a, th.views-field a, .views-summary a')
+            // Process pager, tablesort, and attachment summary links.
+            .find('ul.pager > li > a, th.views-field a, .attachment .views-summary a')
             .each(function () {
               var viewData = {};
               // Construct an object using the settings defaults and then overriding